A call to the user-interface function for allocation of patients to one of two treatments, using covariate-adjusted biased coin design, as proposed by Baldi Antognini A, Zagoraiou M (2011) <Doi:10.1093/biomet/asr021>.
AdjBCD.ui(path, folder = "AdjBCD")the path in which a folder used to store variables will be created.
name of the folder. If it is the default, a folder named "AdjBCD" will be created.
It returns an object of class "carseq".
The function print is used to obtain results. The generic accessor functions assignment, covariate, cov_num, cov_profile and others extract various useful features of the value returned by AdjBCD.ui.
See AdjBCD.
See AdjBCD for allocating patients with complete covariate data; See AdjBCD.sim for allocating patients with covariate data generating mechanism.