A call to the user-iterface function used to allocate patients to one of two treatments using Hu and Hu's general covariate-adaptive randomization method as proposed by Hu Y, Hu F (2012) <Doi:10.1214/12-AOS983>.
HuHuCAR.ui(path, folder = "HuHuCAR")the path in which a folder used to store variables will be created.
name of the folder. If default, a folder named "HuHuCAR" will be created.
It returns an object of class "carseq".
The function print is used to obtain results. The generic accessor functions assignment, covariate, cov_num, cov_profile and others extract various useful features of the value returned by HuHuCAR.ui.
See HuHuCAR
See HuHuCAR for allocating patients with complete covariate data; See HuHuCAR.sim for allocating patients with covariate data generating mechanism.