gives the simulated covariate profile of patients for clincal trials.
data(pats)a dataframe. Each row contains an individual's covariate profile and each column corresponds to a covariate. It contains the following columns
Options are male and female.
Options are "unemployment" (unemp), "part time" (part.), "full time" (full.).
Options are >= 1w, <= 0.5w, 0.5~1w.
Options are unmarried, married, divorced