Printing objects of class "carandom", "careval", "carcomp", "carseq" or "plotrandtest" respectively for different functions, by simple print method.
# S3 method for carandom
print(x, digits = getOption("digits"), prefix = "\t", ...)# S3 method for careval
print(x, digits = getOption("digits"), prefix = "\t", ...)
# S3 method for carcomp
print(x, digits = getOption("digits"), prefix = "\t", ...)
# S3 method for carseq
print(x, digits = getOption("digits"), prefix = "\t", ...)
# S3 method for plotrandtest
print(x, digits = getOption("digits"), prefix = "\t", ...)
objects of class "carandom", "careval", "carcomp", "carseq" or "plotrandtest".
the number of significant digits to be used.
a string, passed to strwrap for displaying the method component of the carandom object, careval object, carcomp object, carseq object and plotrandtest object.
further arguments to be passed to or from methods.
the argument x, invisibly, as for all print
methods.